@@ -63,6 +63,13 @@ int make_fs(const char *device, const char *fstype)
 	ploop_log(0, "%s", cmd);
 	if (system(cmd))
 		return SYSEXIT_MKFS;
+
+	snprintf(cmd, sizeof(cmd), "/sbin/tune2fs -o user_xattr,acl %s </dev/null >/dev/null",
+			part_device);
+	ploop_log(0, "%s", cmd);
+	if (system(cmd))
+		return SYSEXIT_MKFS;
+
 	return 0;
 }
 
@@ -128,7 +135,7 @@ int resize_fs(const char *device)
 			return ret;
 	}
 	snprintf(buf, sizeof(buf), "%s -p %s", prog, part_device);
-	ploop_err(0, "Executing: %s", buf);
+	ploop_log(0, "Executing: %s", buf);
 	ret = system(buf);
 	if (ret) {
 		ploop_err(0, "Failed to resize fs (cmd: %s)", buf);
